@@ -325,7 +325,7 @@ class Package(object):
         # since some time in Feb 2009 PyPI uses different and relative URLs
         # -> complete bullshit
 
-        if url.startswith('../../packages':
+        if url.startswith('../../packages'):
             url = 'http://pypi.python.org/' + url[6:]
 
         try:
